from django.db import models
from django.contrib.sites.models import Site
from django.utils.translation import ugettext as _
from cilantro.managers import SettingsManager

class Settings(models.Model):
    name = models.CharField('Site name', max_length=50, blank=True,
        help_text=_('If left blank the name will be derived from the site or '
        'the hostname'))
    site_logo = models.ImageField(upload_to='cilantro/settings', null=True, blank=True)
    site = models.ForeignKey(Site, related_name='cilantro_settings', null=True, blank=True,
        help_text=_('Leave empty to be the default settings for all sites'))
    footer_content = models.TextField(help_text='Markdown enabled', blank=True)
    google_analytics = models.CharField(max_length=20, null=True, blank=True,
        help_text=_('Just the UA-XXXXXX-XXX code'))

    objects = SettingsManager()

    class Meta(object):
        verbose_name_plural = 'settings'

    def __unicode__(self):
        return u'Cilantro Settings'

    @property
    def site_name(self):
        return self.name or self.site.name

    @property
    def site_domain(self):
        return self.site.domain



from django.db import models
from django.conf import settings
from django.contrib.sites.models import Site

class SettingsManager(models.Manager):
    def get_current(self, request=None):
        obj = self.model()

        if Site._meta.installed:
            try:
                obj = super(SettingsManager, self).get(site__id=settings.SITE_ID)
            except self.model.DoesNotExist:
                try:
                    obj = super(SettingsManager, self).get(site=None)
                except self.model.DoesNotExist:
                    pass

        # if no site is associated, attach a dynamic RequestSite object
        if not obj.site and request:
            host = request.get_host()
            obj.site = Site(name=host, domain=host)

        return obj



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Removing unique constraint on 'Settings', fields ['site']
        db.delete_unique('cilantro_settings', ['site_id'])

        # Adding field 'Settings.name'
        db.add_column('cilantro_settings', 'name', self.gf('django.db.models.fields.CharField')(max_length=50, null=True, blank=True), keep_default=False)

        # Changing field 'Settings.site'
        db.alter_column('cilantro_settings', 'site_id', self.gf('django.db.models.fields.related.ForeignKey')(null=True, to=orm['sites.Site']))


    def backwards(self, orm):
        
        # Deleting field 'Settings.name'
        db.delete_column('cilantro_settings', 'name')

        # User chose to not deal with backwards NULL issues for 'Settings.site'
        raise RuntimeError("Cannot reverse this migration. 'Settings.site' and its values cannot be restored.")

        # Adding unique constraint on 'Settings', fields ['site']
        db.create_unique('cilantro_settings', ['site_id'])


    models = {
        'cilantro.settings': {
            'Meta': {'object_name': 'Settings'},
            'footer_content': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'google_analytics': ('django.db.models.fields.CharField', [], {'max_length': '20', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50', 'null': 'True', 'blank': 'True'}),
            'site': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'cilantro_settings'", 'null': 'True', 'to': "orm['sites.Site']"}),
            'site_logo': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'})
        },
        'sites.site': {
            'Meta': {'ordering': "('domain',)", 'object_name': 'Site', 'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['cilantro']



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Changing field 'Settings.footer_content'
        db.alter_column('cilantro_settings', 'footer_content', self.gf('django.db.models.fields.TextField')(default=''))

        # Changing field 'Settings.name'
        db.alter_column('cilantro_settings', 'name', self.gf('django.db.models.fields.CharField')(default='', max_length=50))


    def backwards(self, orm):
        
        # Changing field 'Settings.footer_content'
        db.alter_column('cilantro_settings', 'footer_content', self.gf('django.db.models.fields.TextField')(null=True))

        # Changing field 'Settings.name'
        db.alter_column('cilantro_settings', 'name', self.gf('django.db.models.fields.CharField')(max_length=50, null=True))


    models = {
        'cilantro.settings': {
            'Meta': {'object_name': 'Settings'},
            'footer_content': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'google_analytics': ('django.db.models.fields.CharField', [], {'max_length': '20', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50', 'blank': 'True'}),
            'site': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'cilantro_settings'", 'null': 'True', 'to': "orm['sites.Site']"}),
            'site_logo': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'})
        },
        'sites.site': {
            'Meta': {'ordering': "('domain',)", 'object_name': 'Site', 'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['cilantro']
